##  Projects
Create Projects to achieve Objectives
  1. Captures the project portfolio
  2. Visualises affected elements of the IT landscape
  3. Defines transformations within the projects
  4. Specifies the detailed impacts on the IT landscape


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27570e047a4410149583d8b2ee589f43_LowRes.png)
